@@ -25,11 +25,10 @@ class SessionElement(DrissionElement):
 
     @property
     def attrs(self) -> dict:
-        """以字典格式返回元素所有属性的名称和值"""
-        attrs = dict(self.inner_ele.attrs)
-        for attr in ['class', 'rel']:
-            if attr in attrs:
-                attrs[attr] = ' '.join(attrs[attr])
+        """返回元素所有属性及值"""
+        attrs = dict()
+        for attr in self.inner_ele.attrs:
+            attrs[attr] = self.attr(attr)
         return attrs
 
     @property
@@ -50,28 +49,43 @@ class SessionElement(DrissionElement):
         return self._inner_ele.tag
 
     @property
-    def parent(self) -> Union[DrissionElement, None]:
-        """requests_html的Element打包了lxml的元素对象，从lxml元素对象读取上下级关系后再重新打包"""
-        try:
-            return SessionElement(Element(element=self.inner_ele.element.xpath('..')[0], url=self.inner_ele.url))
-        except IndexError:
-            return None
+    def parent(self):
+        """父级元素"""
+        return self.parents()
 
     @property
-    def next(self) -> Union[DrissionElement, None]:
+    def next(self):
+        """下一个兄弟元素"""
+        return self.nexts()
+
+    @property
+    def prev(self):
+        """上一个兄弟元素"""
+        return self.prevs()
+
+    def parents(self, num: int = 1):
         """requests_html的Element打包了lxml的元素对象，从lxml元素对象读取上下级关系后再重新打包"""
         try:
             return SessionElement(
-                Element(element=self.inner_ele.element.xpath('./following-sibling::*[1]')[0], url=self.inner_ele.url))
+                Element(element=self.inner_ele.element.xpath(f'..{"/.." * (num - 1)}')[0], url=self.inner_ele.url))
         except IndexError:
             return None
 
-    @property
-    def prev(self) -> Union[DrissionElement, None]:
+    def nexts(self, num: int = 1):
         """requests_html的Element打包了lxml的元素对象，从lxml元素对象读取上下级关系后再重新打包"""
         try:
             return SessionElement(
-                Element(element=self.inner_ele.element.xpath('./preceding-sibling::*[1]')[0], url=self.inner_ele.url))
+                Element(element=self.inner_ele.element.xpath(f'./following-sibling::*[{num}]')[0],
+                        url=self.inner_ele.url))
+        except IndexError:
+            return None
+
+    def prevs(self, num: int = 1):
+        """requests_html的Element打包了lxml的元素对象，从lxml元素对象读取上下级关系后再重新打包"""
+        try:
+            return SessionElement(
+                Element(element=self.inner_ele.element.xpath(f'./preceding-sibling::*[{num}]')[0],
+                        url=self.inner_ele.url))
         except IndexError:
             return None
 
@@ -106,7 +120,14 @@ class SessionElement(DrissionElement):
             if attr == 'href':
                 # 如直接获取attr只能获取相对地址
                 link = self._inner_ele.attrs['href']
-                if link.startswith('?'):  # 避免当相对URL以?开头时requests-html丢失参数的bug
+                if link.lower().startswith(('javascript:', 'mailto:')):
+                    return link
+                elif link.startswith('#'):
+                    if '#' in self.inner_ele.url:
+                        return re.sub(r'#.*', link, self.inner_ele.url)
+                    else:
+                        return f'{self.inner_ele.url}{link}'
+                elif link.startswith('?'):  # 避免当相对URL以?开头时requests-html丢失参数的bug
                     if '?' in self.inner_ele.url:
                         return re.sub(r'\?.*', link, self.inner_ele.url)
                     else:
@@ -114,12 +135,10 @@ class SessionElement(DrissionElement):
                 else:
                     for link in self._inner_ele.absolute_links:
                         return link
+            elif attr == 'src':
+                return self._inner_ele._make_absolute(self._inner_ele.attrs['src'])
             elif attr == 'class':
-                class_str = ''
-                for key, i in enumerate(self._inner_ele.attrs['class']):
-                    class_str += ' ' if key > 0 else ''
-                    class_str += i
-                return class_str
+                return ' '.join(self._inner_ele.attrs['class'])
             elif attr == 'text':
                 return self.text
             else:
